/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
package net.sf.jmatchparser.util.charset.juniversalchardet;

import java.nio.charset.Charset;
import java.nio.charset.spi.CharsetProvider;
import java.util.Arrays;
import java.util.Iterator;

/**
 * Charset provider that provides a convenience charset that uses <a
 * href="http://juniversalchardet.googlecode.com/">jUniversalChardet</a> to dynamically detect
 * the charset it uses for decoding.
 * 
 * <p>
 * The name of this charset is "<tt>jUniversalChardet</tt>".
 * 
 * <p>
 * This class is loaded automatically via SPI when it is in the class path.
 * 
 * <h2>Character sets that can be detected</h2>
 * 
 * <ul>
 * <li>UTF-8</li>
 * <li>Shift_JIS</li>
 * <li>EUC-JP</li>
 * <li>ISO-2022-JP</li>
 * <li>EUC-KR</li>
 * <li>ISO-2022-KR</li>
 * <li>Big5</li>
 * <li>x-euc-tw</li>
 * <li>GB2312</li>
 * <li>GB18030</li>
 * <li>ISO-2022-CN</li>
 * <li>HZ-GB-2312 <i>(not supported by Java by default)</i></li>
 * <li>ISO-8859-5</li> 
 * <li>KOI8-R</li>
 * <li>windows-1251</li> 
 * <li>MacCyrillic</li>
 * <li>IBM866</li>
 * <li>IBM855</li>
 * <li>ISO-8859-7</li> 
 * <li>windows-1253</li>
 * <li>ISO-8859-8</li>
 * <li>windows-1255</li>
 * <li>windows-1252</li>
 * <li>UTF-16BE</li>
 * <li>UTF-16LE</li>
 * <li>UTF-32BE</li>
 * <li>UTF-32LE</li>
 * <li>X-ISO-10646-UCS-4-3412 <i>(not supported by Java by default)</i></li>
 * <li>X-ISO-10646-UCS-4-2143 <i>(not supported by Java by default)</i></li> 
 * </ul>
 */
public class JUniversalChardetCharsetProvider extends CharsetProvider {

	@Override
	public Charset charsetForName(String charsetName) {
			if (charsetName.equals(JUniversalChardetCharset.NAME))
				return JUniversalChardetCharset.getInstance();
		return null;
	}

	@Override
	public Iterator<Charset> charsets() {
		return Arrays.asList(new Charset[] {JUniversalChardetCharset.getInstance()}).iterator();
	}
}
